@@ -32,13 +32,13 @@ class WorldBrowserView: public QTreeView
 {
 public:
     WorldBrowserView(QWidget* parent = 0);
-    virtual void reset();
+    void reset() Q_DECL_OVERRIDE;
 
 protected:
-    void changeEvent(QEvent* event);
-    void drawBranches(QPainter *painter, const QRect &rect, const QModelIndex &index) const;
-    void keyPressEvent(QKeyEvent* e);
-    void contextMenuEvent(QContextMenuEvent* event);
+    void changeEvent(QEvent* event) Q_DECL_OVERRIDE;
+    void drawBranches(QPainter *painter, const QRect &rect, const QModelIndex &index) const Q_DECL_OVERRIDE;
+    void keyPressEvent(QKeyEvent* e) Q_DECL_OVERRIDE;
+    void contextMenuEvent(QContextMenuEvent* event) Q_DECL_OVERRIDE;
     WorldModel* worldModel() { return static_cast<WorldModel*>(model()); }
     const int _windowsDecoSize;
     bool _macStyle;
